.. networking-ovn documentation master file, created by
   sphinx-quickstart on Tue Jul  9 22:26:36 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to networking-ovn's documentation!
========================================================

General Information and Other Project References:

.. toctree::
   :maxdepth: 1

   readme
   features
   contributing
   faq
   refarch/refarch
   install

Testing and Usage Information:

.. toctree::
   :maxdepth: 1

   testing
   dpdk
   containers
   troubleshooting

Design Notes:

.. toctree::
   :maxdepth: 1

   design/data_model
   design/native_dhcp
   design/ovn_worker

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

